@@ -4,9 +4,9 @@ from loguru import logger
 
 log = logger
 log.remove()
-log.add(sink=sys.stderr, level='INFO')
+log.add(sink=sys.stdout, level='INFO', filter='mootdx')
 
 
 def getLogger(level='INFO', **kwargs):
     log.remove()
-    log.add(sink=sys.stdout, level=level, **kwargs)
+    log.add(sink=sys.stdout, level='INFO', filter='mootdx')
