@@ -17,9 +17,10 @@ def txt2csv(infile: str, outfile: str = None) -> pd.DataFrame:
 
     try:
         names = ['date', 'open', 'high', 'low', 'close', 'volume', 'amount']
-        df = pd.read_csv(infile, names=names, header=2, skipfooter=1, index_col='date', engine='python')
+        df = pd.read_csv(infile, names=names, header=2, skipfooter=1, index_col='date', engine='python', encoding='gbk')
 
         # 传参 outfile 目录存在则写文件
+        outfile = outfile if outfile else infile.replace('.txt', '.csv')
         Path(outfile).parent.is_dir() and df.to_csv(outfile)
 
         return df
@@ -28,13 +29,14 @@ def txt2csv(infile: str, outfile: str = None) -> pd.DataFrame:
         log.warning(f'输入文件不存在: {infile}')
         raise ex
     except ValueError as ex:
+        log.exception(ex)
         log.warning(f'无法解析输入文件: {infile}')
         raise ex
 
 
 async def covert(src, dst):
-    log.info('covert...')
-    return await asyncio.get_event_loop().run_in_executor(None, partial(txt2csv, src=src, dst=dst))
+    log.info('covert {}...', src)
+    return await asyncio.get_event_loop().run_in_executor(None, partial(txt2csv, infile=src, outfile=dst))
 
 
 def batch(src, dst):
@@ -49,10 +51,10 @@ def batch(src, dst):
 
     # 分配任务
     for x in glob.glob1(src, '*.txt'):
-        src = str(Path(src, x))
-        dst = str(Path(dst, x.replace('.txt', '.csv')))
+        src_ = str(Path(src, x))
+        dst_ = str(Path(dst, x.replace('.txt', '.csv')))
 
-        task = event.create_task(partial(covert, src=src, dst=dst))
+        task = event.create_task(covert(src=src_, dst=dst_))
         tasks.append(task)
 
     # 执行任务
